@@ -1,3 +1,6 @@
+# Copyright (c) 2024-2025 Xiaokang2022. All rights reserved.
+# Licensed under the MIT License. See LICENSE in the project root for details.
+
 """Base and standard animation classes.
 
 The animation base class can be inherited or called directly. Other standard
@@ -6,7 +9,7 @@ animation classes are best used by direct calls, rather than inheritance.
 
 from __future__ import annotations as _
 
-__all__ = [
+__all__ = (
     "Animation",
     "MoveWindow",
     "MoveTkWidget",
@@ -16,45 +19,57 @@ __all__ = [
     "GradientTkWidget",
     "GradientItem",
     "ScaleFontSize",
-]
+)
 
-import collections.abc
-import typing
+from collections.abc import Sequence
+from typing import TYPE_CHECKING, overload
 
 from ..color import convert, rgb
 from ..core import configs, containers
 from . import controllers
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     import tkinter
+    from collections.abc import Callable
+    from typing import Any
 
     from ..core import virtual
 
 
 class Animation:
-    """Base animation class."""
+    """Base animation class.
+
+    Attributes:
+        command: callback function, which will be called once per frame.
+        controller: a function that controls the animation process.
+        end: end function, which is called once at the end of the animation.
+        repeat: number of repetitions of the animation.
+        repeat_delay: length of the delay before the animation repeats.
+        derivation: whether the callback function is derivative.
+    """
 
     def __init__(
         self,
         duration: int,
-        command: collections.abc.Callable[[float], typing.Any],
+        command: Callable[[float], Any],
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None:
         """
-        * `duration`: duration of the animation, in milliseconds
-        * `command`: callback function, which will be called once per frame
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
-        * `derivation`: whether the callback function is derivative
+        Args:
+            duration: duration of the animation, in milliseconds.
+            command: callback function, which will be called once per frame.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
+            derivation: whether the callback function is derivative.
         """
         self.command = command
         self.controller = controller
@@ -74,35 +89,29 @@ class Animation:
 
     @property
     def active(self) -> bool:
-        """Returns the active state of the animation."""
+        """The active state of the animation."""
         return bool(self._tasks)
 
     @property
     def count(self) -> int:
-        """Returns the number of loops remaining."""
+        """The number of loops remaining."""
         return self._count
 
-    def _repeat(self) -> None:
-        """Processing of the number of repetitions."""
-        self._tasks.clear()
-
-        if self._count != 0:
-            self._count -= 1
-            if task := self.start(delay=self.repeat_delay):
-                self._tasks.append(task)
-        else:
-            self._count = self.repeat
-
-    @typing.overload
+    @overload
     def start(self) -> None: ...
 
-    @typing.overload
+    @overload
     def start(self, *, delay: int) -> str: ...
 
     def start(self, *, delay: int = 0) -> str | None:
         """Start the animation.
 
-        * `delay`: length of the delay before the animation starts
+        Args:
+            delay: length of the delay before the animation starts.
+
+        Returns:
+            If ``delay`` is greater than ``0``, returns the identifier of the
+                scheduled task. Otherwise, returns ``None``.
         """
         if delay > 0:
             return configs.Env.root.after(delay, self.start)
@@ -125,16 +134,21 @@ class Animation:
 
         return None
 
-    @typing.overload
+    @overload
     def stop(self) -> None: ...
 
-    @typing.overload
+    @overload
     def stop(self, *, delay: int) -> str: ...
 
     def stop(self, *, delay: int = 0) -> str | None:
         """Stop the animation.
 
-        * `delay`: length of the delay before the animation stops
+        Args:
+            delay: length of the delay before the animation stops.
+
+        Returns:
+            If ``delay`` is greater than ``0``, returns the identifier of the
+                scheduled task. Otherwise, returns ``None``.
         """
         if delay > 0:
             return configs.Env.root.after(delay, self.stop)
@@ -149,10 +163,22 @@ class Animation:
     def skip(self, count: int = 1) -> None:
         """Skip some loops.
 
-        * `count`: count of skipping
+        Args:
+            count: count of skipping.
         """
         self._count = max(self._count-count, 0)
 
+    def _repeat(self) -> None:
+        """Processing of the number of repetitions."""
+        self._tasks.clear()
+
+        if self._count != 0:
+            self._count -= 1
+            if task := self.start(delay=self.repeat_delay):
+                self._tasks.append(task)
+        else:
+            self._count = self.repeat
+
 
 class MoveWindow(Animation):
     """Animation of moving the window."""
@@ -163,21 +189,22 @@ class MoveWindow(Animation):
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None:
         """
-        * `window`: the window to be moved
-        * `offset`: relative offset of the coordinates
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
+        Args:
+            window: the window to be moved.
+            offset: relative offset of the coordinates.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
         """
         window.update()
         x0, y0, dx, dy = window.winfo_x(), window.winfo_y(), *offset
@@ -189,14 +216,14 @@ class MoveWindow(Animation):
             def callback(p) -> None:
                 window.wm_geometry(f"+{round(x0+dx*p)}+{round(y0+dy*p)}")
 
-        Animation.__init__(
-            self, duration, callback, controller=controller, end=end, fps=fps,
+        super().__init__(
+            duration, callback, controller=controller, end=end, fps=fps,
             repeat=repeat, repeat_delay=repeat_delay,
         )
 
 
 class MoveTkWidget(Animation):
-    """Animation of moving `tkinter.Widget`."""
+    """Animation of moving ``tkinter.Widget``."""
 
     def __init__(
         self,
@@ -204,21 +231,25 @@ class MoveTkWidget(Animation):
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None:
         """
-        * `widget`: the `tkinter.Widget` to be moved
-        * `offset`: relative offset of the coordinates
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
+        Args:
+            widget: the ``tkinter.Widget`` to be moved.
+            offset: relative offset of the coordinates.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
+
+        Raises:
+            RuntimeError: if the widget is not laid out by Place.
         """
         widget.update()
 
@@ -226,8 +257,8 @@ class MoveTkWidget(Animation):
             x0, y0, dx, dy = int(info["x"]), int(info["y"]), *offset
             anchor = info["anchor"]
 
-            Animation.__init__(
-                self, duration, lambda p: widget.place(
+            super().__init__(
+                duration, lambda p: widget.place(
                     x=x0+dx*p, y=y0+dy*p, anchor=anchor),
                 controller=controller, end=end, fps=fps, repeat=repeat,
                 repeat_delay=repeat_delay,
@@ -237,31 +268,31 @@ class MoveTkWidget(Animation):
 
 
 class MoveWidget(Animation):
-    """Animation of moving `virtual.Widget`."""
+    """Animation of moving ``virtual.Widget``."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         widget: virtual.Widget,
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
-        widget: collections.abc.Sequence[virtual.Widget],
+        widget: Sequence[virtual.Widget],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -269,27 +300,28 @@ class MoveWidget(Animation):
 
     def __init__(
         self,
-        widget: virtual.Widget | collections.abc.Sequence[virtual.Widget],
+        widget: virtual.Widget | Sequence[virtual.Widget],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None:
         """
-        * `widget`: the `virtual.Widget` to be moved
-        * `offset`: relative offset of the coordinates
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
+        Args:
+            widget: the ``virtual.Widget`` to be moved.
+            offset: relative offset of the coordinates.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
         """
-        if isinstance(widget, collections.abc.Sequence):
+        if isinstance(widget, Sequence):
             def command(p: float) -> None:
                 dx, dy = offset[0]*p, offset[1]*p
                 for w in widget:
@@ -298,39 +330,38 @@ class MoveWidget(Animation):
             def command(p: float) -> None:
                 widget.move(offset[0]*p, offset[1]*p)
 
-        Animation.__init__(
-            self, duration, command,
-            controller=controller, end=end, fps=fps, repeat=repeat,
-            repeat_delay=repeat_delay, derivation=True,
+        super().__init__(
+            duration, command, controller=controller, end=end, fps=fps,
+            repeat=repeat, repeat_delay=repeat_delay, derivation=True,
         )
 
 
 class MoveElement(Animation):
-    """Animation of moving `virtual.Element`."""
+    """Animation of moving ``virtual.Element``."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         element: virtual.Element,
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
-        element: collections.abc.Sequence[virtual.Element],
+        element: Sequence[virtual.Element],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -338,27 +369,28 @@ class MoveElement(Animation):
 
     def __init__(
         self,
-        element: virtual.Element | collections.abc.Sequence[virtual.Element],
+        element: virtual.Element | Sequence[virtual.Element],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None:
         """
-        * `element`: the `virtual.Element` to be moved
-        * `offset`: relative offset of the coordinates
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
+        Args:
+            element: the ``virtual.Element`` to be moved.
+            offset: relative offset of the coordinates.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
         """
-        if isinstance(element, collections.abc.Sequence):
+        if isinstance(element, Sequence):
             def command(p: float) -> None:
                 dx, dy = offset[0]*p, offset[1]*p
                 for e in element:
@@ -367,17 +399,16 @@ class MoveElement(Animation):
             def command(p: float) -> None:
                 element.move(offset[0]*p, offset[1]*p)
 
-        Animation.__init__(
-            self, duration, command,
-            controller=controller, end=end, fps=fps, repeat=repeat,
-            repeat_delay=repeat_delay, derivation=True,
+        super().__init__(
+            duration, command, controller=controller, end=end, fps=fps,
+            repeat=repeat, repeat_delay=repeat_delay, derivation=True,
         )
 
 
 class MoveItem(Animation):
-    """Animation of moving a item of `tkinter.Canvas`."""
+    """Animation of moving a item of ``tkinter.Canvas``."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
@@ -385,23 +416,23 @@ class MoveItem(Animation):
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
-        item: collections.abc.Sequence[int],
+        item: Sequence[int],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -410,28 +441,29 @@ class MoveItem(Animation):
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
-        item: int | collections.abc.Sequence[int],
+        item: int | Sequence[int],
         offset: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
     ) -> None:
         """
-        * `canvas`: an instance of `tkinter.Canvas` that contains the item
-        * `item`: the item to be moved
-        * `offset`: relative offset of the coordinates
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
+        Args:
+            canvas: an instance of ``tkinter.Canvas`` that contains the item.
+            item: the item to be moved.
+            offset: relative offset of the coordinates.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
         """
-        if isinstance(item, collections.abc.Sequence):
+        if isinstance(item, Sequence):
             def command(p: float) -> None:
                 dx, dy = offset[0]*p, offset[1]*p
                 for i in item:
@@ -440,17 +472,16 @@ class MoveItem(Animation):
             def command(p: float) -> None:
                 canvas.move(item, offset[0]*p, offset[1]*p)
 
-        Animation.__init__(
-            self, duration, command,
-            controller=controller, end=end, fps=fps, repeat=repeat,
-            repeat_delay=repeat_delay, derivation=True,
+        super().__init__(
+            duration, command, controller=controller, end=end, fps=fps,
+            repeat=repeat, repeat_delay=repeat_delay, derivation=True,
         )
 
 
 class GradientTkWidget(Animation):
-    """Animation of making the color of `tkinter.Widget` to be gradient."""
+    """Animation of making the color of ``tkinter.Widget`` to be gradient."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         widget: tkinter.Widget,
@@ -458,24 +489,24 @@ class GradientTkWidget(Animation):
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
-        widget: collections.abc.Sequence[tkinter.Widget],
+        widget: Sequence[tkinter.Widget],
         parameter: str,
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -484,36 +515,40 @@ class GradientTkWidget(Animation):
 
     def __init__(
         self,
-        widget: tkinter.Widget | collections.abc.Sequence[tkinter.Widget],
+        widget: tkinter.Widget | Sequence[tkinter.Widget],
         parameter: str,
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None:
         """
-        * `widget`: the `tkinter.Widget` whose color is to be gradient
-        * `parameter`: parameter name of widget that is to be modified in color
-        * `colors`: a tuple of the initial and ending colors
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
-        * `derivation`: whether the callback function is derivative
+        Args:
+            widget: the ``tkinter.Widget`` whose color is to be gradient.
+            parameter: parameter name of widget that is to be modified in color.
+            colors: a tuple of the initial and ending colors.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
+            derivation: whether the callback function is derivative.
+
+        Raises:
+            ValueError: if any color in ``colors`` is an empty string.
         """
         if not all(colors):
             raise ValueError(f"Null characters ({colors}) cannot be parsed!")
 
         c1, c2 = convert.str_to_rgb(colors[0]), convert.str_to_rgb(colors[1])
 
-        if isinstance(widget, collections.abc.Sequence):
+        if isinstance(widget, Sequence):
             def command(p: float) -> None:
                 value = convert.rgb_to_hex(rgb.transition(c1, c2, p))
                 for w in widget:
@@ -523,17 +558,16 @@ class GradientTkWidget(Animation):
                 widget.configure(
                     {parameter: convert.rgb_to_hex(rgb.transition(c1, c2, p))})
 
-        Animation.__init__(
-            self, duration, command,
-            controller=controller, end=end, fps=fps, repeat=repeat,
-            repeat_delay=repeat_delay, derivation=derivation,
+        super().__init__(
+            duration, command, controller=controller, end=end, fps=fps,
+            repeat=repeat, repeat_delay=repeat_delay, derivation=derivation,
         )
 
 
 class GradientItem(Animation):
     """Animation of making the color of canvas item to be gradient."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
@@ -542,25 +576,25 @@ class GradientItem(Animation):
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
-        item: collections.abc.Sequence[int],
+        item: Sequence[int],
         parameter: str,
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -570,37 +604,41 @@ class GradientItem(Animation):
     def __init__(
         self,
         canvas: tkinter.Canvas | containers.Canvas,
-        item: int | collections.abc.Sequence[int],
+        item: int | Sequence[int],
         parameter: str,
         colors: tuple[str, str],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None:
         """
-        * `canvas`: an instance of `tkinter.Canvas` that contains the item
-        * `item`: item whose color is to be gradient
-        * `parameter`: parameter name of item that is to be modified in color
-        * `colors`: a tuple of the initial and ending colors
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
-        * `derivation`: whether the callback function is derivative
+        Args:
+            canvas: an instance of ``tkinter.Canvas`` that contains the item.
+            item: item whose color is to be gradient.
+            parameter: parameter name of item that is to be modified in color.
+            colors: a tuple of the initial and ending colors.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
+            derivation: whether the callback function is derivative.
+
+        Raises:
+            ValueError: if any color in ``colors`` is an empty string.
         """
         if not all(colors):
             raise ValueError(f"Null characters ({colors}) cannot be parsed!")
 
         c1, c2 = convert.str_to_rgb(colors[0]), convert.str_to_rgb(colors[1])
 
-        if isinstance(item, collections.abc.Sequence):
+        if isinstance(item, Sequence):
             def command(p: float) -> None:
                 value = convert.rgb_to_hex(rgb.transition(c1, c2, p))
                 for i in item:
@@ -610,40 +648,39 @@ class GradientItem(Animation):
                 canvas.itemconfigure(
                     item, {parameter: convert.rgb_to_hex(rgb.transition(c1, c2, p))})
 
-        Animation.__init__(
-            self, duration, command,
-            controller=controller, end=end, fps=fps, repeat=repeat,
-            repeat_delay=repeat_delay, derivation=derivation,
+        super().__init__(
+            duration, command, controller=controller, end=end, fps=fps,
+            repeat=repeat, repeat_delay=repeat_delay, derivation=derivation,
         )
 
 
 class ScaleFontSize(Animation):
-    """Animation of scaling the font size of `virtual.Text`."""
+    """Animation of scaling the font size of ``virtual.Text``."""
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         text: virtual.Text,
         sizes: float,
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None: ...
 
-    @typing.overload
+    @overload
     def __init__(
         self,
         text: virtual.Text,
         sizes: tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
@@ -656,23 +693,24 @@ class ScaleFontSize(Animation):
         sizes: float | tuple[float, float],
         duration: int,
         *,
-        controller: collections.abc.Callable[[float], float] = controllers.linear,
-        end: collections.abc.Callable[[], typing.Any] | None = None,
+        controller: Callable[[float], float] = controllers.linear,
+        end: Callable[[], Any] | None = None,
         fps: int = 30,
         repeat: int = 0,
         repeat_delay: int = 0,
         derivation: bool = False,
     ) -> None:
         """
-        * `text`: an instance of `virtual.Text` that needs to be scaled
-        * `sizes`: a tuple of the initial and ending sizes or target font size
-        * `duration`: duration of the animation, in milliseconds
-        * `controller`: a function that controls the animation process
-        * `end`: end function, which is called once at the end of the animation
-        * `fps`: frame rate of the animation
-        * `repeat`: number of repetitions of the animation
-        * `repeat_delay`: length of the delay before the animation repeats
-        * `derivation`: whether the callback function is derivative
+        Args:
+            text: an instance of ``virtual.Text`` that needs to be scaled.
+            sizes: a tuple of the initial and ending sizes or target font size.
+            duration: duration of the animation, in milliseconds.
+            controller: a function that controls the animation process.
+            end: end function, which is called once at the end of the animation.
+            fps: frame rate of the animation.
+            repeat: number of repetitions of the animation.
+            repeat_delay: length of the delay before the animation repeats.
+            derivation: whether the callback function is derivative.
         """
         if isinstance(sizes, (int, float)):
             sizes = -abs(sizes)
@@ -681,8 +719,8 @@ class ScaleFontSize(Animation):
             sizes = -abs(sizes[0]), -abs(sizes[1])
             sizes = sizes[0], sizes[1] - sizes[0]
 
-        Animation.__init__(
-            self, duration, lambda p: (
+        super().__init__(
+            duration, lambda p: (
                 text.font.config(size=round(sizes[0] + sizes[1]*p)),
                 text.update()),
             controller=controller, end=end, fps=fps, repeat=repeat,
