@@ -1,14 +1,20 @@
+# Copyright (c) 2024-2025 Xiaokang2022. All rights reserved.
+# Licensed under the MIT License. See LICENSE in the project root for details.
+
 """Mapping table between the color names and the RGB codes."""
 
 from __future__ import annotations as _
 
-__all__ = [
+__all__ = (
     "MAPPING_TABLE",
-]
+)
 
-import typing
+from typing import TYPE_CHECKING
 
-MAPPING_TABLE: typing.Final[dict[str, tuple[int, int, int]]] = {
+if TYPE_CHECKING:
+    from typing import Final
+
+MAPPING_TABLE: Final[dict[str, tuple[int, int, int]]] = {
     'alice blue': (240, 248, 255),
     'aliceblue': (240, 248, 255),
     'antique white': (250, 235, 215),
