@@ -1,8 +1,11 @@
-"""All standard `Shape` classes"""
+# Copyright (c) 2024-2025 Xiaokang2022. All rights reserved.
+# Licensed under the MIT License. See LICENSE in the project root for details.
+
+"""All standard ``Shape`` classes."""
 
 from __future__ import annotations as _
 
-__all__ = [
+__all__ = (
     "Line",
     "Rectangle",
     "Oval",
@@ -13,19 +16,22 @@ __all__ = [
     "SemicircularRectangle",
     "SharpRectangle",
     "Parallelogram",
-]
+)
 
 import math
-import typing
 import warnings
+from typing import TYPE_CHECKING
 
-import typing_extensions
+from typing_extensions import override
 
 from ..core import virtual
 
+if TYPE_CHECKING:
+    from typing import Any, Literal
+
 
 class Line(virtual.Shape):
-    """Create a line for a widget"""
+    """Create a line for a widget."""
 
     def __init__(
         self,
@@ -36,35 +42,36 @@ class Line(virtual.Shape):
         points: list[tuple[float, float]] | None = None,
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `points`: key points of line
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            points: key points of line.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.points = [] if points is None else points
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_line(
             0, 0, 0, 0, tags=("fill", "fill"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         points = [(x+self.position[0], y+self.position[1]) for x, y in self.points]
@@ -73,21 +80,21 @@ class Line(virtual.Shape):
 
 
 class Rectangle(virtual.Shape):
-    """Create a rectangle for a widget"""
+    """Create a rectangle for a widget."""
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_rectangle(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         self.widget.master.coords(self.items[0], *self.region())
@@ -96,53 +103,53 @@ class Rectangle(virtual.Shape):
 class Oval(virtual.Shape):
     """Create a oval for a widget"""
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_oval(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         self.widget.master.coords(self.items[0], *self.region())
 
-    @typing_extensions.override
+    @override
     def detect(self, x: float, y: float) -> bool:
-        """Detect whether the specified coordinates are within `Element`"""
+        """Detect whether the specified coordinates are within ``Element``."""
         x1, y1, w, h = *self.position, *self.size
         return math.hypot(2*(x-x1)/w - 1, 2*(y-y1)/h - 1) <= 1
 
 
 class Arc(virtual.Shape):
-    """Create a arc for a widget"""
+    """Create a arc for a widget."""
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_arc(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         self.widget.master.coords(self.items[0], *self.region())
 
 
 class RegularPolygon(virtual.Shape):
-    """Create a regular polygon for a widget"""
+    """Create a regular polygon for a widget."""
 
     def __init__(
         self,
@@ -154,37 +161,38 @@ class RegularPolygon(virtual.Shape):
         angle: float = 0,
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `side`: number of sides of a regular polygon
-        * `angle`: number of radians of a regular polygon rotated clockwise
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            side: number of sides of a regular polygon.
+            angle: number of radians of a regular polygon rotated clockwise.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.side = side
         self.angle = angle
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_polygon(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         r = min(self.size) / 2
@@ -200,7 +208,7 @@ class RegularPolygon(virtual.Shape):
 
 
 class RoundedRectangle(virtual.Shape):
-    """Create a rounded rectangle for a widget"""
+    """Create a rounded rectangle for a widget."""
 
     def __init__(
         self,
@@ -211,25 +219,26 @@ class RoundedRectangle(virtual.Shape):
         radius: int = 5,
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `radius`: radius of the fillet
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            radius: radius of the fillet.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.radius = radius
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [
             self.widget.master.create_rectangle(
                 0, 0, 0, 0, outline="", tags=("fill", "fill"), **self.kwargs),
@@ -261,13 +270,13 @@ class RoundedRectangle(virtual.Shape):
                 0, 0, 0, 0, style="arc", start=-90, tags=("outline", "outline"), **self.kwargs),
         ]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         x, y, w, h = *self.position, *self.size
@@ -298,7 +307,7 @@ class RoundedRectangle(virtual.Shape):
 
 
 class HalfRoundedRectangle(virtual.Shape):
-    """Create a half rounded rectangle for a widget"""
+    """Create a half rounded rectangle for a widget."""
 
     def __init__(
         self,
@@ -307,30 +316,31 @@ class HalfRoundedRectangle(virtual.Shape):
         size: tuple[int, int] | None = None,
         *,
         radius: int = 5,
-        ignore: typing.Literal["left", "right"] = "left",
+        ignore: Literal["left", "right"] = "left",
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `radius`: radius of the fillet
-        * `ignore`: edges to ignore
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            radius: radius of the fillet.
+            ignore: edges to ignore.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.radius = radius
         self.ignore = ignore
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [
             self.widget.master.create_rectangle(
                 0, 0, 0, 0, outline="", tags=("fill", "fill"), **self.kwargs),
@@ -365,13 +375,13 @@ class HalfRoundedRectangle(virtual.Shape):
                 0, 0, 0, 0, style="arc", start=180, tags=("outline", "outline"), **self.kwargs),
         ]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         x, y, w, h = *self.position, *self.size
@@ -408,11 +418,11 @@ class HalfRoundedRectangle(virtual.Shape):
 
 
 class SemicircularRectangle(virtual.Shape):
-    """Create a semicircular rectangle for a widget"""
+    """Create a semicircular rectangle for a widget."""
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [
             self.widget.master.create_arc(
                 0, 0, 0, 0, outline="", extent=180, start=90,
@@ -434,13 +444,13 @@ class SemicircularRectangle(virtual.Shape):
                 0, 0, 0, 0, tags=("fill", "outline"), **self.kwargs),
         ]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         x, y, w, h = *self.position, *self.size
@@ -461,9 +471,9 @@ class SemicircularRectangle(virtual.Shape):
         self.widget.master.coords(self.items[5], x1+r, y1, x2-r+1, y1)
         self.widget.master.coords(self.items[6], x1+r, y2, x2-r+1, y2)
 
-    @typing_extensions.override
+    @override
     def detect(self, x: float, y: float) -> bool:
-        """Detect whether the specified coordinates are within `Element`"""
+        """Detect whether the specified coordinates are within ``Element``."""
         x1, y1, w, h = *self.position, *self.size
         r = h / 2
         if x1+r <= x <= x1+w-r:
@@ -474,7 +484,7 @@ class SemicircularRectangle(virtual.Shape):
 
 
 class SharpRectangle(virtual.Shape):
-    """Create a sharp rectangle for a widget"""
+    """Create a sharp rectangle for a widget."""
 
     def __init__(
         self,
@@ -486,17 +496,18 @@ class SharpRectangle(virtual.Shape):
         ratio: tuple[float, float] = (0.5, 0.5),
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `theta`: number of radians of sharp corners
-        * `ratio`: height ratio of the left and right sharp corners
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            theta: number of radians of sharp corners.
+            ratio: height ratio of the left and right sharp corners.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.theta = theta
         self.ratio = ratio
@@ -504,35 +515,35 @@ class SharpRectangle(virtual.Shape):
             warnings.warn("Parameters are not suitable", UserWarning, 5)
         if math.isclose(abs(self.ratio[0] - self.ratio[1]), 1):
             warnings.warn("Parameters are not suitable", UserWarning, 5)
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_polygon(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         x, y, w, h = *self.position, *self.size
 
         if w < h:
-            warnings.warn("Parameters are not suitable", UserWarning, 5)
+            warnings.warn("Parameters are not suitable.", UserWarning, 5)
 
         dy = [h*value for value in self.ratio]
         dx = [math.tan(self.theta)*y for y in dy]
 
         if sum(dx) > w:
-            warnings.warn("Parameters are not suitable", UserWarning, 5)
+            warnings.warn("Parameters are not suitable.", UserWarning, 5)
 
         x1, y1, x2, y2 = x, y, x + w, y + h
 
@@ -548,7 +559,7 @@ class SharpRectangle(virtual.Shape):
 
 
 class Parallelogram(virtual.Shape):
-    """Create a parallelogram for a widget"""
+    """Create a parallelogram for a widget."""
 
     def __init__(
         self,
@@ -559,43 +570,44 @@ class Parallelogram(virtual.Shape):
         theta: float = math.pi/6,
         name: str | None = None,
         gradient_animation: bool = True,
-        **kwargs,
+        **kwargs: Any,
     ) -> None:
         """
-        * `widget`: parent widget
-        * `relative_position`: position relative to its widgets
-        * `size`: size of element
-        * `theta`: number of radians that the parallelogram is inclined to
-        * `name`: name of element
-        * `gradient_animation`: whether use animation to change color
-        * `kwargs`: extra parameters for CanvasItem
+        Args:
+            widget: parent widget.
+            relative_position: position relative to its widgets.
+            size: size of element.
+            theta: number of radians that the parallelogram is inclined to.
+            name: name of element.
+            gradient_animation: whether use animation to change color.
+            kwargs: extra parameters for CanvasItem.
         """
         self.theta = theta
         if not abs(theta) <= math.pi/3:
-            warnings.warn("Parameters are not suitable", UserWarning, 5)
-        virtual.Shape.__init__(
-            self, widget, relative_position, size,
+            warnings.warn("Parameters are not suitable.", UserWarning, 5)
+        super().__init__(
+            widget, relative_position, size,
             name=name, gradient_animation=gradient_animation, **kwargs)
 
-    @typing_extensions.override
+    @override
     def display(self) -> None:
-        """Display the `Element` on a `Canvas`"""
+        """Display the ``Element`` on a ``Canvas``."""
         self.items = [self.widget.master.create_polygon(
             0, 0, 0, 0, tags=("fill", "fill", "outline", "outline"), **self.kwargs)]
 
-    @typing_extensions.override
+    @override
     def coords(
         self,
         size: tuple[float, float] | None = None,
         position: tuple[float, float] | None = None,
     ) -> None:
-        """Resize the `Element`"""
+        """Resize the ``Element``."""
         super().coords(size, position)
 
         x, y, w, h = *self.position, *self.size
 
         if (dx := h*math.tan(self.theta)) >= w:
-            warnings.warn("Parameters are not suitable", UserWarning, 5)
+            warnings.warn("Parameters are not suitable.", UserWarning, 5)
 
         x1, y1, x2, y2 = x, y, x + w, y + h
 
